import type { PaginationConfiguration } from "@smithy/types";
import { S3Client } from "../S3Client";
/**
 * @public
 */
export interface S3PaginationConfiguration extends PaginationConfiguration {
    client: S3Client;
}
