import { TypeRegistry } from "@smithy/core/schema";
import type { StaticErrorSchema, StaticOperationSchema, StaticStructureSchema, StaticUnionSchema } from "@smithy/types";
export declare var S3ServiceException$: StaticErrorSchema;
export declare var AccessDenied$: StaticErrorSchema;
export declare var BucketAlreadyExists$: StaticErrorSchema;
export declare var BucketAlreadyOwnedByYou$: StaticErrorSchema;
export declare var EncryptionTypeMismatch$: StaticErrorSchema;
export declare var IdempotencyParameterMismatch$: StaticErrorSchema;
export declare var InvalidObjectState$: StaticErrorSchema;
export declare var InvalidRequest$: StaticErrorSchema;
export declare var InvalidWriteOffset$: StaticErrorSchema;
export declare var NoSuchBucket$: StaticErrorSchema;
export declare var NoSuchKey$: StaticErrorSchema;
export declare var NoSuchUpload$: StaticErrorSchema;
export declare var NotFound$: StaticErrorSchema;
export declare var ObjectAlreadyInActiveTierError$: StaticErrorSchema;
export declare var ObjectNotInActiveTierError$: StaticErrorSchema;
export declare var TooManyParts$: StaticErrorSchema;
/**
 * TypeRegistry instances containing modeled errors.
 * @internal
 *
 */
export declare const errorTypeRegistries: TypeRegistry[];
export declare var AbacStatus$: StaticStructureSchema;
export declare var AbortIncompleteMultipartUpload$: StaticStructureSchema;
export declare var AbortMultipartUploadOutput$: StaticStructureSchema;
export declare var AbortMultipartUploadRequest$: StaticStructureSchema;
export declare var AccelerateConfiguration$: StaticStructureSchema;
export declare var AccessControlPolicy$: StaticStructureSchema;
export declare var AccessControlTranslation$: StaticStructureSchema;
export declare var AnalyticsAndOperator$: StaticStructureSchema;
export declare var AnalyticsConfiguration$: StaticStructureSchema;
export declare var AnalyticsExportDestination$: StaticStructureSchema;
export declare var AnalyticsS3BucketDestination$: StaticStructureSchema;
export declare var BlockedEncryptionTypes$: StaticStructureSchema;
export declare var Bucket$: StaticStructureSchema;
export declare var BucketInfo$: StaticStructureSchema;
export declare var BucketLifecycleConfiguration$: StaticStructureSchema;
export declare var BucketLoggingStatus$: StaticStructureSchema;
export declare var Checksum$: StaticStructureSchema;
export declare var CommonPrefix$: StaticStructureSchema;
export declare var CompletedMultipartUpload$: StaticStructureSchema;
export declare var CompletedPart$: StaticStructureSchema;
export declare var CompleteMultipartUploadOutput$: StaticStructureSchema;
export declare var CompleteMultipartUploadRequest$: StaticStructureSchema;
export declare var Condition$: StaticStructureSchema;
export declare var ContinuationEvent$: StaticStructureSchema;
export declare var CopyObjectOutput$: StaticStructureSchema;
export declare var CopyObjectRequest$: StaticStructureSchema;
export declare var CopyObjectResult$: StaticStructureSchema;
export declare var CopyPartResult$: StaticStructureSchema;
export declare var CORSConfiguration$: StaticStructureSchema;
export declare var CORSRule$: StaticStructureSchema;
export declare var CreateBucketConfiguration$: StaticStructureSchema;
export declare var CreateBucketMetadataConfigurationRequest$: StaticStructureSchema;
export declare var CreateBucketMetadataTableConfigurationRequest$: StaticStructureSchema;
export declare var CreateBucketOutput$: StaticStructureSchema;
export declare var CreateBucketRequest$: StaticStructureSchema;
export declare var CreateMultipartUploadOutput$: StaticStructureSchema;
export declare var CreateMultipartUploadRequest$: StaticStructureSchema;
export declare var CreateSessionOutput$: StaticStructureSchema;
export declare var CreateSessionRequest$: StaticStructureSchema;
export declare var CSVInput$: StaticStructureSchema;
export declare var CSVOutput$: StaticStructureSchema;
export declare var DefaultRetention$: StaticStructureSchema;
export declare var Delete$: StaticStructureSchema;
export declare var DeleteBucketAnalyticsConfigurationRequest$: StaticStructureSchema;
export declare var DeleteBucketCorsRequest$: StaticStructureSchema;
export declare var DeleteBucketEncryptionRequest$: StaticStructureSchema;
export declare var DeleteBucketIntelligentTieringConfigurationRequest$: StaticStructureSchema;
export declare var DeleteBucketInventoryConfigurationRequest$: StaticStructureSchema;
export declare var DeleteBucketLifecycleRequest$: StaticStructureSchema;
export declare var DeleteBucketMetadataConfigurationRequest$: StaticStructureSchema;
export declare var DeleteBucketMetadataTableConfigurationRequest$: StaticStructureSchema;
export declare var DeleteBucketMetricsConfigurationRequest$: StaticStructureSchema;
export declare var DeleteBucketOwnershipControlsRequest$: StaticStructureSchema;
export declare var DeleteBucketPolicyRequest$: StaticStructureSchema;
export declare var DeleteBucketReplicationRequest$: StaticStructureSchema;
export declare var DeleteBucketRequest$: StaticStructureSchema;
export declare var DeleteBucketTaggingRequest$: StaticStructureSchema;
export declare var DeleteBucketWebsiteRequest$: StaticStructureSchema;
export declare var DeletedObject$: StaticStructureSchema;
export declare var DeleteMarkerEntry$: StaticStructureSchema;
export declare var DeleteMarkerReplication$: StaticStructureSchema;
export declare var DeleteObjectOutput$: StaticStructureSchema;
export declare var DeleteObjectRequest$: StaticStructureSchema;
export declare var DeleteObjectsOutput$: StaticStructureSchema;
export declare var DeleteObjectsRequest$: StaticStructureSchema;
export declare var DeleteObjectTaggingOutput$: StaticStructureSchema;
export declare var DeleteObjectTaggingRequest$: StaticStructureSchema;
export declare var DeletePublicAccessBlockRequest$: StaticStructureSchema;
export declare var Destination$: StaticStructureSchema;
export declare var DestinationResult$: StaticStructureSchema;
export declare var Encryption$: StaticStructureSchema;
export declare var EncryptionConfiguration$: StaticStructureSchema;
export declare var EndEvent$: StaticStructureSchema;
export declare var _Error$: StaticStructureSchema;
export declare var ErrorDetails$: StaticStructureSchema;
export declare var ErrorDocument$: StaticStructureSchema;
export declare var EventBridgeConfiguration$: StaticStructureSchema;
export declare var ExistingObjectReplication$: StaticStructureSchema;
export declare var FilterRule$: StaticStructureSchema;
export declare var GetBucketAbacOutput$: StaticStructureSchema;
export declare var GetBucketAbacRequest$: StaticStructureSchema;
export declare var GetBucketAccelerateConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketAccelerateConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketAclOutput$: StaticStructureSchema;
export declare var GetBucketAclRequest$: StaticStructureSchema;
export declare var GetBucketAnalyticsConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketAnalyticsConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketCorsOutput$: StaticStructureSchema;
export declare var GetBucketCorsRequest$: StaticStructureSchema;
export declare var GetBucketEncryptionOutput$: StaticStructureSchema;
export declare var GetBucketEncryptionRequest$: StaticStructureSchema;
export declare var GetBucketIntelligentTieringConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketIntelligentTieringConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketInventoryConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketInventoryConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketLifecycleConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketLifecycleConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketLocationOutput$: StaticStructureSchema;
export declare var GetBucketLocationRequest$: StaticStructureSchema;
export declare var GetBucketLoggingOutput$: StaticStructureSchema;
export declare var GetBucketLoggingRequest$: StaticStructureSchema;
export declare var GetBucketMetadataConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketMetadataConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketMetadataConfigurationResult$: StaticStructureSchema;
export declare var GetBucketMetadataTableConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketMetadataTableConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketMetadataTableConfigurationResult$: StaticStructureSchema;
export declare var GetBucketMetricsConfigurationOutput$: StaticStructureSchema;
export declare var GetBucketMetricsConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketNotificationConfigurationRequest$: StaticStructureSchema;
export declare var GetBucketOwnershipControlsOutput$: StaticStructureSchema;
export declare var GetBucketOwnershipControlsRequest$: StaticStructureSchema;
export declare var GetBucketPolicyOutput$: StaticStructureSchema;
export declare var GetBucketPolicyRequest$: StaticStructureSchema;
export declare var GetBucketPolicyStatusOutput$: StaticStructureSchema;
export declare var GetBucketPolicyStatusRequest$: StaticStructureSchema;
export declare var GetBucketReplicationOutput$: StaticStructureSchema;
export declare var GetBucketReplicationRequest$: StaticStructureSchema;
export declare var GetBucketRequestPaymentOutput$: StaticStructureSchema;
export declare var GetBucketRequestPaymentRequest$: StaticStructureSchema;
export declare var GetBucketTaggingOutput$: StaticStructureSchema;
export declare var GetBucketTaggingRequest$: StaticStructureSchema;
export declare var GetBucketVersioningOutput$: StaticStructureSchema;
export declare var GetBucketVersioningRequest$: StaticStructureSchema;
export declare var GetBucketWebsiteOutput$: StaticStructureSchema;
export declare var GetBucketWebsiteRequest$: StaticStructureSchema;
export declare var GetObjectAclOutput$: StaticStructureSchema;
export declare var GetObjectAclRequest$: StaticStructureSchema;
export declare var GetObjectAttributesOutput$: StaticStructureSchema;
export declare var GetObjectAttributesParts$: StaticStructureSchema;
export declare var GetObjectAttributesRequest$: StaticStructureSchema;
export declare var GetObjectLegalHoldOutput$: StaticStructureSchema;
export declare var GetObjectLegalHoldRequest$: StaticStructureSchema;
export declare var GetObjectLockConfigurationOutput$: StaticStructureSchema;
export declare var GetObjectLockConfigurationRequest$: StaticStructureSchema;
export declare var GetObjectOutput$: StaticStructureSchema;
export declare var GetObjectRequest$: StaticStructureSchema;
export declare var GetObjectRetentionOutput$: StaticStructureSchema;
export declare var GetObjectRetentionRequest$: StaticStructureSchema;
export declare var GetObjectTaggingOutput$: StaticStructureSchema;
export declare var GetObjectTaggingRequest$: StaticStructureSchema;
export declare var GetObjectTorrentOutput$: StaticStructureSchema;
export declare var GetObjectTorrentRequest$: StaticStructureSchema;
export declare var GetPublicAccessBlockOutput$: StaticStructureSchema;
export declare var GetPublicAccessBlockRequest$: StaticStructureSchema;
export declare var GlacierJobParameters$: StaticStructureSchema;
export declare var Grant$: StaticStructureSchema;
export declare var Grantee$: StaticStructureSchema;
export declare var HeadBucketOutput$: StaticStructureSchema;
export declare var HeadBucketRequest$: StaticStructureSchema;
export declare var HeadObjectOutput$: StaticStructureSchema;
export declare var HeadObjectRequest$: StaticStructureSchema;
export declare var IndexDocument$: StaticStructureSchema;
export declare var Initiator$: StaticStructureSchema;
export declare var InputSerialization$: StaticStructureSchema;
export declare var IntelligentTieringAndOperator$: StaticStructureSchema;
export declare var IntelligentTieringConfiguration$: StaticStructureSchema;
export declare var IntelligentTieringFilter$: StaticStructureSchema;
export declare var InventoryConfiguration$: StaticStructureSchema;
export declare var InventoryDestination$: StaticStructureSchema;
export declare var InventoryEncryption$: StaticStructureSchema;
export declare var InventoryFilter$: StaticStructureSchema;
export declare var InventoryS3BucketDestination$: StaticStructureSchema;
export declare var InventorySchedule$: StaticStructureSchema;
export declare var InventoryTableConfiguration$: StaticStructureSchema;
export declare var InventoryTableConfigurationResult$: StaticStructureSchema;
export declare var InventoryTableConfigurationUpdates$: StaticStructureSchema;
export declare var JournalTableConfiguration$: StaticStructureSchema;
export declare var JournalTableConfigurationResult$: StaticStructureSchema;
export declare var JournalTableConfigurationUpdates$: StaticStructureSchema;
export declare var JSONInput$: StaticStructureSchema;
export declare var JSONOutput$: StaticStructureSchema;
export declare var LambdaFunctionConfiguration$: StaticStructureSchema;
export declare var LifecycleExpiration$: StaticStructureSchema;
export declare var LifecycleRule$: StaticStructureSchema;
export declare var LifecycleRuleAndOperator$: StaticStructureSchema;
export declare var LifecycleRuleFilter$: StaticStructureSchema;
export declare var ListBucketAnalyticsConfigurationsOutput$: StaticStructureSchema;
export declare var ListBucketAnalyticsConfigurationsRequest$: StaticStructureSchema;
export declare var ListBucketIntelligentTieringConfigurationsOutput$: StaticStructureSchema;
export declare var ListBucketIntelligentTieringConfigurationsRequest$: StaticStructureSchema;
export declare var ListBucketInventoryConfigurationsOutput$: StaticStructureSchema;
export declare var ListBucketInventoryConfigurationsRequest$: StaticStructureSchema;
export declare var ListBucketMetricsConfigurationsOutput$: StaticStructureSchema;
export declare var ListBucketMetricsConfigurationsRequest$: StaticStructureSchema;
export declare var ListBucketsOutput$: StaticStructureSchema;
export declare var ListBucketsRequest$: StaticStructureSchema;
export declare var ListDirectoryBucketsOutput$: StaticStructureSchema;
export declare var ListDirectoryBucketsRequest$: StaticStructureSchema;
export declare var ListMultipartUploadsOutput$: StaticStructureSchema;
export declare var ListMultipartUploadsRequest$: StaticStructureSchema;
export declare var ListObjectsOutput$: StaticStructureSchema;
export declare var ListObjectsRequest$: StaticStructureSchema;
export declare var ListObjectsV2Output$: StaticStructureSchema;
export declare var ListObjectsV2Request$: StaticStructureSchema;
export declare var ListObjectVersionsOutput$: StaticStructureSchema;
export declare var ListObjectVersionsRequest$: StaticStructureSchema;
export declare var ListPartsOutput$: StaticStructureSchema;
export declare var ListPartsRequest$: StaticStructureSchema;
export declare var LocationInfo$: StaticStructureSchema;
export declare var LoggingEnabled$: StaticStructureSchema;
export declare var MetadataConfiguration$: StaticStructureSchema;
export declare var MetadataConfigurationResult$: StaticStructureSchema;
export declare var MetadataEntry$: StaticStructureSchema;
export declare var MetadataTableConfiguration$: StaticStructureSchema;
export declare var MetadataTableConfigurationResult$: StaticStructureSchema;
export declare var MetadataTableEncryptionConfiguration$: StaticStructureSchema;
export declare var Metrics$: StaticStructureSchema;
export declare var MetricsAndOperator$: StaticStructureSchema;
export declare var MetricsConfiguration$: StaticStructureSchema;
export declare var MultipartUpload$: StaticStructureSchema;
export declare var NoncurrentVersionExpiration$: StaticStructureSchema;
export declare var NoncurrentVersionTransition$: StaticStructureSchema;
export declare var NotificationConfiguration$: StaticStructureSchema;
export declare var NotificationConfigurationFilter$: StaticStructureSchema;
export declare var _Object$: StaticStructureSchema;
export declare var ObjectIdentifier$: StaticStructureSchema;
export declare var ObjectLockConfiguration$: StaticStructureSchema;
export declare var ObjectLockLegalHold$: StaticStructureSchema;
export declare var ObjectLockRetention$: StaticStructureSchema;
export declare var ObjectLockRule$: StaticStructureSchema;
export declare var ObjectPart$: StaticStructureSchema;
export declare var ObjectVersion$: StaticStructureSchema;
export declare var OutputLocation$: StaticStructureSchema;
export declare var OutputSerialization$: StaticStructureSchema;
export declare var Owner$: StaticStructureSchema;
export declare var OwnershipControls$: StaticStructureSchema;
export declare var OwnershipControlsRule$: StaticStructureSchema;
export declare var ParquetInput$: StaticStructureSchema;
export declare var Part$: StaticStructureSchema;
export declare var PartitionedPrefix$: StaticStructureSchema;
export declare var PolicyStatus$: StaticStructureSchema;
export declare var Progress$: StaticStructureSchema;
export declare var ProgressEvent$: StaticStructureSchema;
export declare var PublicAccessBlockConfiguration$: StaticStructureSchema;
export declare var PutBucketAbacRequest$: StaticStructureSchema;
export declare var PutBucketAccelerateConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketAclRequest$: StaticStructureSchema;
export declare var PutBucketAnalyticsConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketCorsRequest$: StaticStructureSchema;
export declare var PutBucketEncryptionRequest$: StaticStructureSchema;
export declare var PutBucketIntelligentTieringConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketInventoryConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketLifecycleConfigurationOutput$: StaticStructureSchema;
export declare var PutBucketLifecycleConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketLoggingRequest$: StaticStructureSchema;
export declare var PutBucketMetricsConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketNotificationConfigurationRequest$: StaticStructureSchema;
export declare var PutBucketOwnershipControlsRequest$: StaticStructureSchema;
export declare var PutBucketPolicyRequest$: StaticStructureSchema;
export declare var PutBucketReplicationRequest$: StaticStructureSchema;
export declare var PutBucketRequestPaymentRequest$: StaticStructureSchema;
export declare var PutBucketTaggingRequest$: StaticStructureSchema;
export declare var PutBucketVersioningRequest$: StaticStructureSchema;
export declare var PutBucketWebsiteRequest$: StaticStructureSchema;
export declare var PutObjectAclOutput$: StaticStructureSchema;
export declare var PutObjectAclRequest$: StaticStructureSchema;
export declare var PutObjectLegalHoldOutput$: StaticStructureSchema;
export declare var PutObjectLegalHoldRequest$: StaticStructureSchema;
export declare var PutObjectLockConfigurationOutput$: StaticStructureSchema;
export declare var PutObjectLockConfigurationRequest$: StaticStructureSchema;
export declare var PutObjectOutput$: StaticStructureSchema;
export declare var PutObjectRequest$: StaticStructureSchema;
export declare var PutObjectRetentionOutput$: StaticStructureSchema;
export declare var PutObjectRetentionRequest$: StaticStructureSchema;
export declare var PutObjectTaggingOutput$: StaticStructureSchema;
export declare var PutObjectTaggingRequest$: StaticStructureSchema;
export declare var PutPublicAccessBlockRequest$: StaticStructureSchema;
export declare var QueueConfiguration$: StaticStructureSchema;
export declare var RecordExpiration$: StaticStructureSchema;
export declare var RecordsEvent$: StaticStructureSchema;
export declare var Redirect$: StaticStructureSchema;
export declare var RedirectAllRequestsTo$: StaticStructureSchema;
export declare var RenameObjectOutput$: StaticStructureSchema;
export declare var RenameObjectRequest$: StaticStructureSchema;
export declare var ReplicaModifications$: StaticStructureSchema;
export declare var ReplicationConfiguration$: StaticStructureSchema;
export declare var ReplicationRule$: StaticStructureSchema;
export declare var ReplicationRuleAndOperator$: StaticStructureSchema;
export declare var ReplicationRuleFilter$: StaticStructureSchema;
export declare var ReplicationTime$: StaticStructureSchema;
export declare var ReplicationTimeValue$: StaticStructureSchema;
export declare var RequestPaymentConfiguration$: StaticStructureSchema;
export declare var RequestProgress$: StaticStructureSchema;
export declare var RestoreObjectOutput$: StaticStructureSchema;
export declare var RestoreObjectRequest$: StaticStructureSchema;
export declare var RestoreRequest$: StaticStructureSchema;
export declare var RestoreStatus$: StaticStructureSchema;
export declare var RoutingRule$: StaticStructureSchema;
export declare var S3KeyFilter$: StaticStructureSchema;
export declare var S3Location$: StaticStructureSchema;
export declare var S3TablesDestination$: StaticStructureSchema;
export declare var S3TablesDestinationResult$: StaticStructureSchema;
export declare var ScanRange$: StaticStructureSchema;
export declare var SelectObjectContentOutput$: StaticStructureSchema;
export declare var SelectObjectContentRequest$: StaticStructureSchema;
export declare var SelectParameters$: StaticStructureSchema;
export declare var ServerSideEncryptionByDefault$: StaticStructureSchema;
export declare var ServerSideEncryptionConfiguration$: StaticStructureSchema;
export declare var ServerSideEncryptionRule$: StaticStructureSchema;
export declare var SessionCredentials$: StaticStructureSchema;
export declare var SimplePrefix$: StaticStructureSchema;
export declare var SourceSelectionCriteria$: StaticStructureSchema;
export declare var SSEKMS$: StaticStructureSchema;
export declare var SseKmsEncryptedObjects$: StaticStructureSchema;
export declare var SSEKMSEncryption$: StaticStructureSchema;
export declare var SSES3$: StaticStructureSchema;
export declare var Stats$: StaticStructureSchema;
export declare var StatsEvent$: StaticStructureSchema;
export declare var StorageClassAnalysis$: StaticStructureSchema;
export declare var StorageClassAnalysisDataExport$: StaticStructureSchema;
export declare var Tag$: StaticStructureSchema;
export declare var Tagging$: StaticStructureSchema;
export declare var TargetGrant$: StaticStructureSchema;
export declare var TargetObjectKeyFormat$: StaticStructureSchema;
export declare var Tiering$: StaticStructureSchema;
export declare var TopicConfiguration$: StaticStructureSchema;
export declare var Transition$: StaticStructureSchema;
export declare var UpdateBucketMetadataInventoryTableConfigurationRequest$: StaticStructureSchema;
export declare var UpdateBucketMetadataJournalTableConfigurationRequest$: StaticStructureSchema;
export declare var UpdateObjectEncryptionRequest$: StaticStructureSchema;
export declare var UpdateObjectEncryptionResponse$: StaticStructureSchema;
export declare var UploadPartCopyOutput$: StaticStructureSchema;
export declare var UploadPartCopyRequest$: StaticStructureSchema;
export declare var UploadPartOutput$: StaticStructureSchema;
export declare var UploadPartRequest$: StaticStructureSchema;
export declare var VersioningConfiguration$: StaticStructureSchema;
export declare var WebsiteConfiguration$: StaticStructureSchema;
export declare var WriteGetObjectResponseRequest$: StaticStructureSchema;
export declare var AnalyticsFilter$: StaticUnionSchema;
export declare var MetricsFilter$: StaticUnionSchema;
export declare var ObjectEncryption$: StaticUnionSchema;
export declare var SelectObjectContentEventStream$: StaticUnionSchema;
export declare var AbortMultipartUpload$: StaticOperationSchema;
export declare var CompleteMultipartUpload$: StaticOperationSchema;
export declare var CopyObject$: StaticOperationSchema;
export declare var CreateBucket$: StaticOperationSchema;
export declare var CreateBucketMetadataConfiguration$: StaticOperationSchema;
export declare var CreateBucketMetadataTableConfiguration$: StaticOperationSchema;
export declare var CreateMultipartUpload$: StaticOperationSchema;
export declare var CreateSession$: StaticOperationSchema;
export declare var DeleteBucket$: StaticOperationSchema;
export declare var DeleteBucketAnalyticsConfiguration$: StaticOperationSchema;
export declare var DeleteBucketCors$: StaticOperationSchema;
export declare var DeleteBucketEncryption$: StaticOperationSchema;
export declare var DeleteBucketIntelligentTieringConfiguration$: StaticOperationSchema;
export declare var DeleteBucketInventoryConfiguration$: StaticOperationSchema;
export declare var DeleteBucketLifecycle$: StaticOperationSchema;
export declare var DeleteBucketMetadataConfiguration$: StaticOperationSchema;
export declare var DeleteBucketMetadataTableConfiguration$: StaticOperationSchema;
export declare var DeleteBucketMetricsConfiguration$: StaticOperationSchema;
export declare var DeleteBucketOwnershipControls$: StaticOperationSchema;
export declare var DeleteBucketPolicy$: StaticOperationSchema;
export declare var DeleteBucketReplication$: StaticOperationSchema;
export declare var DeleteBucketTagging$: StaticOperationSchema;
export declare var DeleteBucketWebsite$: StaticOperationSchema;
export declare var DeleteObject$: StaticOperationSchema;
export declare var DeleteObjects$: StaticOperationSchema;
export declare var DeleteObjectTagging$: StaticOperationSchema;
export declare var DeletePublicAccessBlock$: StaticOperationSchema;
export declare var GetBucketAbac$: StaticOperationSchema;
export declare var GetBucketAccelerateConfiguration$: StaticOperationSchema;
export declare var GetBucketAcl$: StaticOperationSchema;
export declare var GetBucketAnalyticsConfiguration$: StaticOperationSchema;
export declare var GetBucketCors$: StaticOperationSchema;
export declare var GetBucketEncryption$: StaticOperationSchema;
export declare var GetBucketIntelligentTieringConfiguration$: StaticOperationSchema;
export declare var GetBucketInventoryConfiguration$: StaticOperationSchema;
export declare var GetBucketLifecycleConfiguration$: StaticOperationSchema;
export declare var GetBucketLocation$: StaticOperationSchema;
export declare var GetBucketLogging$: StaticOperationSchema;
export declare var GetBucketMetadataConfiguration$: StaticOperationSchema;
export declare var GetBucketMetadataTableConfiguration$: StaticOperationSchema;
export declare var GetBucketMetricsConfiguration$: StaticOperationSchema;
export declare var GetBucketNotificationConfiguration$: StaticOperationSchema;
export declare var GetBucketOwnershipControls$: StaticOperationSchema;
export declare var GetBucketPolicy$: StaticOperationSchema;
export declare var GetBucketPolicyStatus$: StaticOperationSchema;
export declare var GetBucketReplication$: StaticOperationSchema;
export declare var GetBucketRequestPayment$: StaticOperationSchema;
export declare var GetBucketTagging$: StaticOperationSchema;
export declare var GetBucketVersioning$: StaticOperationSchema;
export declare var GetBucketWebsite$: StaticOperationSchema;
export declare var GetObject$: StaticOperationSchema;
export declare var GetObjectAcl$: StaticOperationSchema;
export declare var GetObjectAttributes$: StaticOperationSchema;
export declare var GetObjectLegalHold$: StaticOperationSchema;
export declare var GetObjectLockConfiguration$: StaticOperationSchema;
export declare var GetObjectRetention$: StaticOperationSchema;
export declare var GetObjectTagging$: StaticOperationSchema;
export declare var GetObjectTorrent$: StaticOperationSchema;
export declare var GetPublicAccessBlock$: StaticOperationSchema;
export declare var HeadBucket$: StaticOperationSchema;
export declare var HeadObject$: StaticOperationSchema;
export declare var ListBucketAnalyticsConfigurations$: StaticOperationSchema;
export declare var ListBucketIntelligentTieringConfigurations$: StaticOperationSchema;
export declare var ListBucketInventoryConfigurations$: StaticOperationSchema;
export declare var ListBucketMetricsConfigurations$: StaticOperationSchema;
export declare var ListBuckets$: StaticOperationSchema;
export declare var ListDirectoryBuckets$: StaticOperationSchema;
export declare var ListMultipartUploads$: StaticOperationSchema;
export declare var ListObjects$: StaticOperationSchema;
export declare var ListObjectsV2$: StaticOperationSchema;
export declare var ListObjectVersions$: StaticOperationSchema;
export declare var ListParts$: StaticOperationSchema;
export declare var PutBucketAbac$: StaticOperationSchema;
export declare var PutBucketAccelerateConfiguration$: StaticOperationSchema;
export declare var PutBucketAcl$: StaticOperationSchema;
export declare var PutBucketAnalyticsConfiguration$: StaticOperationSchema;
export declare var PutBucketCors$: StaticOperationSchema;
export declare var PutBucketEncryption$: StaticOperationSchema;
export declare var PutBucketIntelligentTieringConfiguration$: StaticOperationSchema;
export declare var PutBucketInventoryConfiguration$: StaticOperationSchema;
export declare var PutBucketLifecycleConfiguration$: StaticOperationSchema;
export declare var PutBucketLogging$: StaticOperationSchema;
export declare var PutBucketMetricsConfiguration$: StaticOperationSchema;
export declare var PutBucketNotificationConfiguration$: StaticOperationSchema;
export declare var PutBucketOwnershipControls$: StaticOperationSchema;
export declare var PutBucketPolicy$: StaticOperationSchema;
export declare var PutBucketReplication$: StaticOperationSchema;
export declare var PutBucketRequestPayment$: StaticOperationSchema;
export declare var PutBucketTagging$: StaticOperationSchema;
export declare var PutBucketVersioning$: StaticOperationSchema;
export declare var PutBucketWebsite$: StaticOperationSchema;
export declare var PutObject$: StaticOperationSchema;
export declare var PutObjectAcl$: StaticOperationSchema;
export declare var PutObjectLegalHold$: StaticOperationSchema;
export declare var PutObjectLockConfiguration$: StaticOperationSchema;
export declare var PutObjectRetention$: StaticOperationSchema;
export declare var PutObjectTagging$: StaticOperationSchema;
export declare var PutPublicAccessBlock$: StaticOperationSchema;
export declare var RenameObject$: StaticOperationSchema;
export declare var RestoreObject$: StaticOperationSchema;
export declare var SelectObjectContent$: StaticOperationSchema;
export declare var UpdateBucketMetadataInventoryTableConfiguration$: StaticOperationSchema;
export declare var UpdateBucketMetadataJournalTableConfiguration$: StaticOperationSchema;
export declare var UpdateObjectEncryption$: StaticOperationSchema;
export declare var UploadPart$: StaticOperationSchema;
export declare var UploadPartCopy$: StaticOperationSchema;
export declare var WriteGetObjectResponse$: StaticOperationSchema;
