import type { Paginator } from "@smithy/types";
import { ListPartsCommandInput, ListPartsCommandOutput } from "../commands/ListPartsCommand";
import { S3PaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListParts: (config: S3PaginationConfiguration, input: ListPartsCommandInput, ...rest: any[]) => Paginator<ListPartsCommandOutput>;
